import { NavBar, DatePicker } from 'antd-mobile'

import { useEffect, useState } from 'react'
import { useSelector } from "react-redux";
import { useMemo } from 'react'
import _ from 'lodash'
import classNames from 'classnames'
import dayjs from "dayjs"


import './index.scss'
import DailyBill from './components/DayBill';

const Month = () => {

    // 按月分组
    const billList = useSelector(state => state.bill.billList)

    const monthGroup = useMemo(() => {
        // return出去计算之后的值
        return _.groupBy(billList, (item) => dayjs(item.date).format('YYYY-MM'))
    }, [billList])

    // 控制时间选择器打开关闭
    const [dateVisible, setDateVisible] = useState(false)

    // 时间选择框确实事件
    const dateConfirm = (date) => {
        // 关闭弹框
        setDateVisible(false)
        const month = dayjs(date).format('YYYY-MM')
        const monthKey = dayjs(date).format('YYYY-MM')
        setMonthList(monthGroup[monthKey])
        setCurrentMonth(month)
    }

    const [currentMonth, setCurrentMonth] = useState(() => {
        return dayjs().format('YYYY-MM')
    })

    const [currentMonthList, setMonthList] = useState([])

    const dayGroup = useMemo(() => {
        const group = _.groupBy(currentMonthList, (item) => dayjs(item.date).format('YYYY-MM-DD'))
        return {
          dayKeys: Object.keys(group),
          group
        }
      }, [currentMonthList])

    // 计算统计
    const monthResult = useMemo(() => {
        if (currentMonthList === undefined){
            return {'pay':0,'income':0,'total':0}
        }
        // 支出  /  收入  / 结余
        const pay = currentMonthList.filter(item => item.type === 'pay').reduce((a, c) => a + c.money, 0)
        const income = currentMonthList.filter(item => item.type === 'income').reduce((a, c) => a + c.money, 0)
        return {
          pay,
          income,
          total: (pay + income)
        }
      }, [currentMonthList])

        // 初始化的时候把当前月的统计数据显示出来
    useEffect(() => {
    const nowDate = dayjs().format('YYYY-MM')
    // 边界值控制
    if (monthGroup[nowDate]) {
      setMonthList(monthGroup[nowDate])
    }
  }, [monthGroup])


  return (
    <div className="monthlyBill">
      <NavBar className="nav" backArrow={false}>
        月度收支
      </NavBar>
      <div className="content">
        <div className="header">
          {/* 时间切换区域 */}
          <div className="date" onClick={() => setDateVisible(true)}>
            <span className="text">
              {currentMonth} 月账单
            </span>
            <span className={classNames('arrow', dateVisible && 'expand')}></span>
          </div>
          {/* 统计区域 */}
          <div className='twoLineOverview'>
          <div className="item">
              <span className="money">{monthResult.pay.toFixed(2)}</span>
              <span className="type">支出</span>
            </div>
            <div className="item">
              <span className="money">{monthResult.income.toFixed(2)}</span>
              <span className="type">收入</span>
            </div>
            <div className="item">
              <span className="money">{monthResult.total.toFixed(2)}</span>
              <span className="type">结余</span>
            </div>
          </div>
          {/* 时间选择器 */}
          <DatePicker
            className="kaDate"
            title="记账日期"
            precision="month"
            visible={dateVisible}
            onCancel={() => setDateVisible(false)}
            onConfirm={dateConfirm}
            onClose={() => setDateVisible(false)}
            max={new Date()}
          />
        </div>
        {/* 单日列表 */}
{dayGroup.dayKeys.map(dayKey => (
  <DailyBill key={dayKey} date={dayKey} billList={dayGroup.group[dayKey]} />
))}
      </div>
    </div >
  )
}

export default Month
